trident.optims package
======================

Submodules
----------

trident.optims.pytorch\_constraints module
------------------------------------------

.. automodule:: trident.optims.pytorch_constraints
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.pytorch\_losses module
-------------------------------------

.. automodule:: trident.optims.pytorch_losses
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.pytorch\_metrics module
--------------------------------------

.. automodule:: trident.optims.pytorch_metrics
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.pytorch\_optimizers module
-----------------------------------------

.. automodule:: trident.optims.pytorch_optimizers
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.pytorch\_profiling module
----------------------------------------

.. automodule:: trident.optims.pytorch_profiling
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.pytorch\_regularizers module
-------------------------------------------

.. automodule:: trident.optims.pytorch_regularizers
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.pytorch\_trainer module
--------------------------------------

.. automodule:: trident.optims.pytorch_trainer
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.tensorflow\_constraints module
---------------------------------------------

.. automodule:: trident.optims.tensorflow_constraints
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.tensorflow\_losses module
----------------------------------------

.. automodule:: trident.optims.tensorflow_losses
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.tensorflow\_metrics module
-----------------------------------------

.. automodule:: trident.optims.tensorflow_metrics
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.tensorflow\_optimizers module
--------------------------------------------

.. automodule:: trident.optims.tensorflow_optimizers
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.tensorflow\_regularizers module
----------------------------------------------

.. automodule:: trident.optims.tensorflow_regularizers
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.tensorflow\_trainer module
-----------------------------------------

.. automodule:: trident.optims.tensorflow_trainer
   :members:
   :undoc-members:
   :show-inheritance:

trident.optims.trainers module
------------------------------

.. automodule:: trident.optims.trainers
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: trident.optims
   :members:
   :undoc-members:
   :show-inheritance:
